"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var { __ΩAutoIncrement } = require('@deepkit/type');
var { __ΩPrimaryKey } = require('@deepkit/type');
var { __ΩPostgres } = require('@deepkit/type');
var { __ΩEntity } = require('@deepkit/type');
var { __ΩUnique } = require('@deepkit/type');
var { __ΩReference } = require('@deepkit/type');
const globals_1 = require("@jest/globals");
const sql_1 = require("@deepkit/sql");
const type_1 = require("@deepkit/type");
const postgres_adapter_1 = require("../src/postgres-adapter");
const orm_1 = require("@deepkit/orm");
(0, globals_1.test)('custom type', async () => {
    class post {
        constructor() {
            this.id = 0;
            this.slug = '';
            this.content = '';
        }
    }
    post.__type = [() => __ΩAutoIncrement, () => __ΩPrimaryKey, 'id', () => 0, () => __ΩPostgres, "VARCHAR(255)", 'type', 'slug', () => "", 'content', () => "", 'P\'n!n"K3#>$P&P.&4\'Mo%"K3(>)&3*>+5'];
    const reflection = type_1.ReflectionClass.from(post);
    reflection.getProperty('slug');
    const adapter = new postgres_adapter_1.PostgresDatabaseAdapter({ host: '127.0.0.1', database: 'postgres', user: 'postgres' });
    const [postTable] = adapter.platform.createTables(orm_1.DatabaseEntityRegistry.from([post]));
    (0, globals_1.expect)(postTable.getColumn('slug').type).toBe('varchar');
    (0, globals_1.expect)(postTable.getColumn('slug').size).toBe(255);
    (0, globals_1.expect)(postTable.getColumn('content').type).toBe('text');
    await (0, sql_1.schemaMigrationRoundTrip)([post], adapter);
});
(0, globals_1.test)('default expression', async () => {
    class post {
        constructor() {
            this.id = 0;
            this.str = '';
            this.no = 3;
            this.json = {};
            this.created = new Date;
        }
    }
    post.__type = [() => __ΩAutoIncrement, () => __ΩPrimaryKey, 'id', () => 0, () => __ΩPostgres, "VARCHAR(255)", 'type', "abc", 'default', 'str', () => "", () => __ΩPostgres, 34.5, 'no', () => 3, () => __ΩPostgres, "jsonb", 'json', () => ({}), () => __ΩPostgres, "now()", 'defaultExpr', 'created', () => new Date, 'opt', 'P\'n!n"K3#>$P&P.&4\'.(4)Mo%"K3*>+P\'P.-4)Mo,"K3.>/P"P.14\'PM4)Mo0"K32>3PTP.546Mo4"K37>8)3985'];
    const adapter = new postgres_adapter_1.PostgresDatabaseAdapter({ host: '127.0.0.1', database: 'postgres', user: 'postgres' });
    const [postTable] = adapter.platform.createTables(orm_1.DatabaseEntityRegistry.from([post]));
    (0, globals_1.expect)(postTable.getColumn('str').defaultValue).toBe('abc');
    (0, globals_1.expect)(postTable.getColumn('no').defaultValue).toBe(34.5);
    (0, globals_1.expect)(postTable.getColumn('created').defaultExpression).toBe('now()');
    await (0, sql_1.schemaMigrationRoundTrip)([post], adapter);
});
(0, globals_1.test)('numbers', async () => {
    class post {
        constructor() {
            this.id = 0;
            this.int8 = 0;
            this.uint8 = 0;
            this.int16 = 0;
            this.uint16 = 0;
            this.int32 = 0;
            this.uint32 = 0;
            this.float32 = 0;
            this.default = 0;
        }
    }
    post.__type = [() => __ΩAutoIncrement, () => __ΩPrimaryKey, 'id', () => 0, 'int8', () => 0, 'uint8', () => 0, 'int16', () => 0, 'uint16', () => 0, 'int32', () => 0, 'uint32', () => 0, 'float32', () => 0, 'default', () => 0, 'P(!n!n"K3#>$("3%>&(%3\'>((#3)>*(&3+>,($3->.(\'3/>0()31>2\'33>45'];
    const adapter = new postgres_adapter_1.PostgresDatabaseAdapter({ host: '127.0.0.1', database: 'postgres', user: 'postgres' });
    const [postTable] = adapter.platform.createTables(orm_1.DatabaseEntityRegistry.from([post]));
    const DDL = await (0, sql_1.schemaMigrationRoundTrip)([post], adapter);
    (0, globals_1.expect)(DDL).toContain(`CREATE TABLE "post" (
    "id" SERIAL,
    "int8" smallint NOT NULL DEFAULT 0,
    "uint8" smallint NOT NULL DEFAULT 0,
    "int16" smallint NOT NULL DEFAULT 0,
    "uint16" smallint NOT NULL DEFAULT 0,
    "int32" integer NOT NULL DEFAULT 0,
    "uint32" integer NOT NULL DEFAULT 0,
    "float32" real NOT NULL DEFAULT 0,
    "default" double precision NOT NULL DEFAULT 0,
    PRIMARY KEY ("id")
)`);
});
var __ΩUser = [() => __ΩEntity, "user", 'name', () => __ΩAutoIncrement, () => __ΩPrimaryKey, 'id', () => __ΩUnique, 'username', 'created', 'deleted', 'logins', 'PP."4#Mo!"P\'n$n%K4&P&n\'K4(T4))4*\'4+M'];
var __ΩPost = [() => __ΩEntity, "post", 'name', () => __ΩAutoIncrement, () => __ΩPrimaryKey, 'id', () => __ΩUser, () => __ΩReference, 'user', 'created', () => __ΩUnique, 'slag', 'title', 'content', 'PP."4#Mo!"P\'n$n%K4&Pn\'n(K4)T4*P&n+K4,&4-&4.M'];
(0, globals_1.test)('postgres', async () => {
    await (0, sql_1.schemaMigrationRoundTrip)([(0, type_1.typeOf)([], [() => __ΩUser, 'n!']), (0, type_1.typeOf)([], [() => __ΩPost, 'n!'])], new postgres_adapter_1.PostgresDatabaseAdapter({ host: 'localhost', database: 'postgres', user: 'postgres' }));
});
//# sourceMappingURL=migration.spec.js.map